@@ -7,7 +7,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = "1.38_02";
+our $VERSION = "1.41_50";
 XSLoader::load 'IO', $VERSION;
 
 sub import {
@@ -53,7 +53,7 @@ in one go.  The IO modules belonging to the core are:
 
 Some other IO modules don't belong to the perl core but can be loaded
 as well if they have been installed from CPAN.  You can discover which
-ones exist by searching for "^IO::" on http://search.cpan.org.
+ones exist by searching for "^IO::" on L<http://search.cpan.org>.
 
 For more information on any of these modules, please see its respective
 documentation.
